"use client";

import React from "react";

import confetti from "canvas-confetti";
import { useTranslations } from "next-intl";

import {
	ColumnDefinition,
	CustomDataTable,
} from "@/components/common/table/cutom-data-table";
import BlurFade from "@/components/ui/blur-fade";
import NumberTicker from "@/components/ui/number-ticker";
import ShinyButton from "@/components/ui/shiny-button";
import { Locale } from "@/i18n/routing";

type Points = {
	status: "active" | "inactive" | "pending";
	point_number: number;
	name: string;
	description: string;
};

const pointsData: Points[] = [
	{
		status: "active",
		point_number: 100,
		name: "Point_One",
		description: "Point one is active and operational.",
	},
	{
		status: "inactive",
		point_number: 200,
		name: "Point_Two",
		description: "Point two is currently inactive.",
	},
	{
		status: "active",
		point_number: 300,
		name: "Point_Three",
		description: "Point three is actively processing requests.",
	},
	{
		status: "active",
		point_number: 400,
		name: "Point_Four",
		description: "Point four is under review for quality assurance.",
	},
	{
		status: "inactive",
		point_number: 500,
		name: "Point_Five",
		description: "Point five has been deactivated for maintenance.",
	},
	{
		status: "active",
		point_number: 600,
		name: "Point_Six",
		description: "Point six is fully functional and active.",
	},
	{
		status: "active",
		point_number: 700,
		name: "Point_Seven",

		description: "Point seven is pending approval from the management.",
	},
	{
		status: "active",
		point_number: 800,
		name: "Point_Eight",
		description: "Point eight is operating without any issues.",
	},
	{
		status: "inactive",
		point_number: 900,
		name: "Point_Nine",
		description: "Point nine has been temporarily disabled.",
	},
	{
		status: "active",
		point_number: 100,
		name: "Point_Ten",
		description: "Point ten is being reviewed for compliance.",
	},
];

function PointsTable({ language }: { language: Locale }) {
	const t = useTranslations("UserAccount");

	const columns: ColumnDefinition<Points>[] = [
		{
			header: t("PackageName"),
			key: "name",
			render: () => (
				<button className="h-[31px] w-[75px] rounded-sm bg-[#E9ECEF] text-sm text-[#6C757D]">
					PDF
				</button>
			),
		},
		{
			header: t("Status"),
			key: "status",
			align: "center",
			render: (value) => (
				<div className="flex min-w-[250px] justify-center py-4">
					<div
						className={`w-fit rounded-3xl px-2 py-1 text-center text-[12px] leading-[18px] text-white ${value === "active" ? "bg-[#2895C8]" : "bg-[#11B981]"} `}
					>
						{t(value)}
					</div>
				</div>
			),
		},
		{
			header: t("NumberOfPoints"),
			key: "point_number",
			render: (value) => (
				<div className="flex items-center gap-1 text-custom-fourth">
					<NumberTicker value={value as number} />
					{t("Point")}
				</div>
			),
		},
		{
			header: t("Description"),
			key: "description",
			className: "text-custom-fifth text-sm",
			align: "center",
		},
		{
			header: t("Operations"),
			key: "action",
			className: "text-custom-fifth text-sm",
			align: "center",
			render: () => (
				<div className="flex items-center justify-end gap-3">
					<ShinyButton className="rounded-sm bg-[#E9ECEF]">
						<p className="text-sm text-custom-primary-accent">
							{t("PackageSubscription")}
						</p>
					</ShinyButton>
					<ShinyButton className="rounded-sm bg-[#606676]">
						<p className="text-sm text-white">{t("Details")}</p>
					</ShinyButton>
				</div>
			),
		},
	];

	const handleConfetti = React.useCallback(() => {
		const end = Date.now() + 3 * 1000; // 3 seconds
		const colors = ["#a786ff", "#fd8bbc", "#eca184", "#f8deb1"];

		const frame = () => {
			if (Date.now() > end) return;

			confetti({
				particleCount: 2,
				angle: 60,
				spread: 55,
				startVelocity: 60,
				origin: { x: 0, y: 0.5 },
				colors: colors,
			});
			confetti({
				particleCount: 2,
				angle: 120,
				spread: 55,
				startVelocity: 60,
				origin: { x: 1, y: 0.5 },
				colors: colors,
			});

			requestAnimationFrame(frame);
		};

		frame();
	}, []);

	React.useEffect(() => {
		if (typeof window !== "undefined") {
			handleConfetti();
		}
	}, [handleConfetti]);

	return (
		<div
			className="my-12 px-3 pb-8"
			style={{ boxShadow: "0px 2px 48px 0px #0000000A" }}
		>
			<BlurFade inView className="mb-10 text-2xl text-custom-fourth">
				{t("ListOfPointsOffers")}
			</BlurFade>
			<CustomDataTable columns={columns} data={pointsData} locale={language} />
		</div>
	);
}

export default PointsTable;
